@@ -45,6 +45,10 @@ using std::endl;
 #  include <sidplayfp/builders/exsid.h>
 #endif
 
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+#  include <sidplayfp/builders/usbsid.h>
+#endif
+
 // Wide-chars are not yet supported here
 #undef SEPARATOR
 #define SEPARATOR "/"
@@ -164,7 +168,6 @@ int ConsolePlayer::args(int argc, const char *argv[])
     }
 
     // default arg options
-    m_driver.output = output_t::SOUNDCARD;
     m_driver.file   = false;
     m_driver.info   = false;
 
@@ -190,6 +193,11 @@ int ConsolePlayer::args(int argc, const char *argv[])
                 displayDebugArgs ();
                 return 0;
             }
+            else if (!std::strcmp(&argv[i][1], "-version"))
+            {
+                displayVersion();
+                return 0;
+            }
 
             else if (argv[i][1] == 'b')
             {
@@ -209,9 +217,25 @@ int ConsolePlayer::args(int argc, const char *argv[])
 #ifdef FEAT_NEW_PLAY_API
             else if (strncmp (&argv[i][1], "fo", 2) == 0)
             {
-                if (argv[i][3] == '\0')
+                m_fadeAfter = true;
+                int j = 3;
+                if (argv[i][j] == 'a')
+                {
+                    j++;
+                }
+                else if (argv[i][j] == 'b')
+                {
+                    j++;
+                    m_fadeAfter = false;
+                }
+                if (argv[i][j] == '\0')
                     err = true;
-                m_fadeoutTime = (uint_least32_t) atoi (&argv[i][3]);
+                int fadeoutTime = (uint_least32_t) atoi (&argv[i][j]);
+                if (fadeoutTime < 0)
+                {
+                    err = true;
+                }
+                m_fadeoutTime = static_cast<uint_least32_t>(fadeoutTime);
             }
 #endif
             else if (argv[i][1] == 'f')
@@ -431,7 +455,7 @@ int ConsolePlayer::args(int argc, const char *argv[])
             else if (std::strcmp (&argv[i][1], "cws") == 0)
             {
                 m_combinedWaveformsStrength  = SidConfig::STRONG;
-            }	
+            }
 #endif
             // File format conversions
             else if (argv[i][1] == 'w')
@@ -490,6 +514,14 @@ int ConsolePlayer::args(int argc, const char *argv[])
             }
 #endif // HAVE_SIDPLAYFP_BUILDERS_EXSID_H
 
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+            else if (std::strcmp (&argv[i][1], "-usbsid") == 0)
+            {
+                m_driver.sid    = EMU_USBSID;
+                m_driver.output = output_t::NONE;
+            }
+#endif // HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+
             // These are for debug
             else if (std::strcmp (&argv[i][1], "-none") == 0)
             {
@@ -675,7 +707,7 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " --help-debug debug help menu" << endl
         << " -b<num>      set start time in [mins:]secs[.milli] format (default: 0)" << endl
 #ifdef FEAT_NEW_PLAY_API
-        << " -fo<num>     set fade-out time in seconds (default: 0)" << endl
+        << " -fo[a|b]<num> set fade-out time in seconds, ends a(fter) or starts b(efore) actual song end time (default: 0=no fade out)" << endl
 #endif
         << " -f<num>      set frequency in Hz (default: "
         << SidConfig::DEFAULT_SAMPLING_FREQ << ")" << endl
@@ -740,6 +772,13 @@ void ConsolePlayer::displayArgs (const char *arg)
         if (hs.availDevices ())
             out << " --exsid      enable exSID support" << endl;
     }
+#endif
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+    {
+        USBSIDBuilder us("");
+        if (us.availDevices ())
+            out << " --usbsid     enable USBSID support" << endl;
+    }
 #endif
     out << endl
         << "Home Page: " PACKAGE_URL << endl;
