@@ -88,6 +88,8 @@ bool Audio_OUT123::open(AudioConfig &cfg)
             throw error("Unable to allocate memory for sample buffers.");
         }
 
+        // Force precision
+        cfg.precision = 16;
         // Setup internal Config
         _settings = cfg;
         return true;
