@@ -90,6 +90,11 @@ const char ConsolePlayer::HARDSID_ID[] = "HardSID";
 const char ConsolePlayer::EXSID_ID[] = "exSID";
 #endif
 
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+#   include <sidplayfp/builders/usbsid.h>
+const char ConsolePlayer::USBSID_ID[] = "USBSID";
+#endif
+
 #ifdef FEAT_REGS_DUMP_SID
 uint16_t freqTablePal[]
 {
@@ -249,7 +254,7 @@ double getRecommendedFilterRange(const std::string& author)
         double adjustment = it->second;
         return (adjustment * 20. - 1.) / 39.;
     }
-    return -1;
+    return -1.;
 }
 #else
 double getRecommendedFilterCurve(const std::string& author)
@@ -390,6 +395,9 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         if (emulation.powerOnDelay >= 0)
             m_engCfg.powerOnDelay    = emulation.powerOnDelay;
 
+        // Set default output
+        m_driver.output = output_t::SOUNDCARD;
+
         if (!emulation.engine.empty())
         {
             if (emulation.engine.compare(TEXT("RESIDFP")) == 0)
@@ -413,6 +421,13 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
                 m_driver.sid    = EMU_EXSID;
                 m_driver.output = output_t::NONE;
             }
+#endif
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+            else if (emulation.engine.compare(TEXT("USBSID")) == 0)
+            {
+                m_driver.sid    = EMU_USBSID;
+                m_driver.output = output_t::NONE;
+            }
 #endif
             else if (emulation.engine.compare(TEXT("NONE")) == 0)
             {
@@ -424,6 +439,7 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
     m_verboseLevel = (m_iniCfg.sidplay2()).verboseLevel;
 #ifdef FEAT_NEW_PLAY_API
     m_fadeoutTime = 0;
+    m_fadeAfter = false;
 #endif
     createOutput (output_t::NONE, nullptr);
     createSidEmu (EMU_NONE, nullptr);
@@ -621,9 +637,18 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
 
             if (m_autofilter && (tuneInfo->numberOfInfoStrings() == 3))
             {
-                frange = getRecommendedFilterRange(tuneInfo->infoString(1));
-                if (m_verboseLevel > 1)
-                    cerr << "Recommended filter range: " << frange << endl;
+                double rfr = getRecommendedFilterRange(tuneInfo->infoString(1));
+                if (rfr < 0.)
+                {
+                    if (m_verboseLevel > 1)
+                        cerr << "No recommended filter range available" << endl;
+                }
+                else
+                {
+                    if (m_verboseLevel > 1)
+                        cerr << "Recommended filter range: " << rfr << endl;
+                    frange = rfr;
+                }
             }
 
             if (m_frange.has_value())
@@ -647,9 +672,18 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
 #ifndef FEAT_FILTER_RANGE
             if (m_autofilter && (tuneInfo->numberOfInfoStrings() == 3))
             {
-                fcurve = getRecommendedFilterCurve(tuneInfo->infoString(1));
-                if (m_verboseLevel > 1)
-                    cerr << "Recommended filter curve: " << fcurve << endl;
+                double rfc = getRecommendedFilterCurve(tuneInfo->infoString(1));
+                if (rfc < 0.)
+                {
+                    if (m_verboseLevel > 1)
+                        cerr << "No recommended filter curve available" << endl;
+                }
+                else
+                {
+                    if (m_verboseLevel > 1)
+                        cerr << "Recommended filter curve: " << rfc << endl;
+                    fcurve = rfc;
+                }
             }
 #endif
             if (m_fcurve.has_value())
@@ -742,6 +776,23 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
     }
 #endif // HAVE_SIDPLAYFP_BUILDERS_EXSID_H
 
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+    case EMU_USBSID:
+    {
+        try
+        {
+            USBSIDBuilder *us = new USBSIDBuilder( USBSID_ID );
+
+            m_engCfg.sidEmulation = us;
+            if (!us->getStatus()) goto createSidEmu_error;
+            us->create ((m_engine.info ()).maxsids());
+            if (!us->getStatus()) goto createSidEmu_error;
+        }
+        catch (std::bad_alloc const &ba) {}
+        break;
+    }
+#endif // HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+
     default:
         // Emulation Not yet handled
         // This default case results in the default
@@ -872,7 +923,7 @@ bool ConsolePlayer::open (void)
                     (tuneInfo->clockSpeed() != SidTuneInfo::CLOCK_PAL)
                     ? FREQ_NTSC
                     : FREQ_PAL;
-                length /= 
+                length /=
                     (m_engCfg.defaultC64Model == SidConfig::NTSC) ||
                     (m_engCfg.defaultC64Model == SidConfig::OLD_NTSC)
                     ? FREQ_NTSC
@@ -885,7 +936,8 @@ bool ConsolePlayer::open (void)
     // Set up the play timer
     m_timer.stop = m_timer.length;
 #ifdef FEAT_NEW_PLAY_API
-    m_timer.stop += m_fadeoutTime;
+    if (m_fadeAfter)
+        m_timer.stop += m_fadeoutTime;
 #endif
 
     if (m_timer.valid)
@@ -931,18 +983,6 @@ void ConsolePlayer::close ()
     createSidEmu    (EMU_NONE, nullptr);
     m_engine.load   (nullptr);
     m_engine.config (m_engCfg);
-
-    if (m_quietLevel < 2)
-    {   // Correctly leave ansi mode and get prompt to
-        // end up in a suitable location
-        if ((m_iniCfg.console ()).ansi) {
-            cerr << '\x1b' << "[?25h";
-            cerr << '\x1b' << "[0m";
-        }
-#ifndef _WIN32
-        cerr << endl;
-#endif
-    }
 }
 
 // Flush any hardware sid fifos so all music is played
@@ -960,6 +1000,11 @@ void ConsolePlayer::emuflush ()
         ((exSIDBuilder *)m_engCfg.sidEmulation)->flush ();
         break;
 #endif // HAVE_SIDPLAYFP_BUILDERS_EXSID_H
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+    case EMU_USBSID:
+        ((USBSIDBuilder *)m_engCfg.sidEmulation)->flush ();
+        break;
+#endif // HAVE_SIDPLAYFP_BUILDERS_USBSID_H
     default:
         break;
     }
@@ -1001,7 +1046,7 @@ bool ConsolePlayer::play()
             int samples = m_engine.play(2000);
             if (samples < 0) UNLIKELY
             {
-                cerr << m_engine.error();
+                displayError (m_engine.error());
                 m_state = playerError;
                 return false;
             }
@@ -1020,7 +1065,7 @@ bool ConsolePlayer::play()
         uint_least32_t samples = m_engine.play(buffer, length);
         if ((samples < length) || !m_engine.isPlaying()) UNLIKELY
         {
-            cerr << m_engine.error();
+            displayError (m_engine.error());
             m_state = playerError;
             return false;
         }
