@@ -102,6 +102,7 @@ typedef enum
     /* The following should disable the soundcard */
     EMU_HARDSID,
     EMU_EXSID,
+    EMU_USBSID,
     EMU_SIDSTATION,
     EMU_COMMODORE,
     EMU_SIDSYN,
@@ -144,6 +145,9 @@ private:
 #ifdef HAVE_SIDPLAYFP_BUILDERS_EXSID_H
     static const char  EXSID_ID[];
 #endif
+#ifdef HAVE_SIDPLAYFP_BUILDERS_USBSID_H
+    static const char  USBSID_ID[];
+#endif
 #ifdef HAVE_TSID
     TSID               m_tsid;
 #endif
@@ -169,6 +173,11 @@ private:
 #endif
 #ifdef FEAT_NEW_PLAY_API
     uint_least32_t     m_fadeoutTime;
+    /*
+     * fade out after song end
+     * if true fade out time will be added to song duration
+     */
+    bool               m_fadeAfter;
 #endif
 #ifdef FEAT_REGS_DUMP_SID
     uint8_t            m_registers[3][32];
@@ -255,6 +264,7 @@ private:
 
     // Command line args
     void displayArgs    (const char *arg = nullptr);
+    void displayVersion ();
 
     bool createOutput   (output_t driver, const SidTuneInfo *tuneInfo);
     bool createSidEmu   (SIDEMUS emu, const SidTuneInfo *tuneInfo);
